@@ -7,20 +7,17 @@ import { t } from '@grafana/i18n';
 import { locationService } from '@grafana/runtime';
 import { Alert } from '@grafana/ui';
 import { EntityNotFound } from 'app/core/components/PageNotFound/EntityNotFound';
-import { useAppNotification } from 'app/core/copy/appNotification';
 import { AlertingPageWrapper } from 'app/features/alerting/unified/components/AlertingPageWrapper';
+import { ProvisioningAlert, ProvisionedResource } from 'app/features/alerting/unified/components/Provisioning';
+import { isK8sEntityProvisioned } from 'app/features/alerting/unified/utils/k8s/utils';
 import { stringifyErrorLike } from 'app/features/alerting/unified/utils/misc';
 import { isLLMPluginEnabled } from 'app/features/dashboard/components/GenAI/utils';
 
-import {
-  AlertEnrichment,
-  ReplaceAlertEnrichmentApiArg,
-  generatedAPI,
-} from '../../api/clients/alertenrichment/v1beta1/endpoints.gen';
+import { AlertEnrichment, generatedAPI } from '../../api/clients/alertenrichment/v1beta1/endpoints.gen';
 import { enrichmentNav } from '../navigation';
 
 import { AlertEnrichmentForm } from './form/AlertEnrichmentForm';
-import { AlertEnrichmentFormData, getInitialFormData, formDataToEnrichmentSpec } from './form/form';
+import { AlertEnrichmentFormData, getInitialFormData, useEnrichmentUpdate } from './form/form';
 import { useEditEnrichmentNavModel } from './navigation';
 
 function EditEnrichment() {
@@ -59,50 +56,37 @@ function EditEnrichment() {
 }
 
 function ExistingEnrichmentForm({ enrichment }: { enrichment: AlertEnrichment }) {
-  const [replaceAlertEnrichment, { isLoading: isUpdating }] = generatedAPI.useReplaceAlertEnrichmentMutation();
-  const notifyApp = useAppNotification();
   const { value: llmEnabled } = useAsync(isLLMPluginEnabled);
 
   const onCancel = () => {
     locationService.push(enrichmentNav.list);
   };
 
+  // Use the custom hook for enrichment updates
+  const { updateEnrichment, isLoading: isUpdating } = useEnrichmentUpdate('enrichmentForm', () => {
+    // Redirect to enrichments list page after successful update
+    locationService.push(enrichmentNav.list);
+  });
+
   const onSubmit = async (formData: AlertEnrichmentFormData) => {
-    if (!enrichment.metadata) {
-      notifyApp.error(t('alert-enrichment.metadata-error', 'Invalid enrichment metadata'));
-      return;
-    }
-
-    const updatedEnrichment: AlertEnrichment = {
-      metadata: { name: enrichment.metadata.name },
-      spec: formDataToEnrichmentSpec(formData),
-    };
-
-    const apiArg: ReplaceAlertEnrichmentApiArg = {
-      name: enrichment.metadata.name || '',
-      alertEnrichment: updatedEnrichment,
-    };
-
-    try {
-      await replaceAlertEnrichment(apiArg).unwrap();
-      notifyApp.success(t('alert-enrichment.update-success', 'Alert enrichment updated successfully!'));
-      // Redirect to enrichments list page after successful update
-      locationService.push(enrichmentNav.list);
-    } catch (err) {
-      console.error('Failed to update alert enrichment:', err);
-      notifyApp.error(t('alert-enrichment.update-error', 'Failed to update alert enrichment'), stringifyErrorLike(err));
-    }
+    await updateEnrichment(enrichment, formData);
   };
 
+  const enrichmentIsProvisioned = isK8sEntityProvisioned(enrichment);
+
   const editPayload = getInitialFormData(enrichment);
   return (
-    <AlertEnrichmentForm
-      onSubmit={onSubmit}
-      onCancel={onCancel}
-      editPayload={editPayload}
-      isLoading={isUpdating}
-      llmEnabled={!!llmEnabled}
-    />
+    <>
+      {enrichmentIsProvisioned && <ProvisioningAlert resource={ProvisionedResource.AlertEnrichment} />}
+      <AlertEnrichmentForm
+        onSubmit={onSubmit}
+        onCancel={onCancel}
+        editPayload={editPayload}
+        isLoading={isUpdating}
+        llmEnabled={!!llmEnabled}
+        readOnly={enrichmentIsProvisioned}
+      />
+    </>
   );
 }
 
